@@ -6,9 +6,9 @@ use Message::Passing::DSL;
 use Carp qw/ confess /;
 use MooX::Options flavour => [qw( pass_through )], protect_argv => 0;
 use namespace::clean -except => [qw/ meta new_with_options parse_options _options_data _options_config/];
-use 5.8.4;
+use 5.008004;
 
-our $VERSION = '0.109';
+our $VERSION = '0.110';
 $VERSION = eval $VERSION;
 
 around 'parse_options' => sub {
